Class: Google::Cloud::Bigquery::Storage::V1::AppendRowsRequest::ProtoData
- Inherits:
-
Object
- Object
- Google::Cloud::Bigquery::Storage::V1::AppendRowsRequest::ProtoData
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/bigquery/storage/v1/storage.rb
Overview
ProtoData contains the data rows and schema when constructing append requests.
Instance Attribute Summary collapse
-
#rows ⇒ ::Google::Cloud::Bigquery::Storage::V1::ProtoRows
Required.
-
#writer_schema ⇒ ::Google::Cloud::Bigquery::Storage::V1::ProtoSchema
Optional.
Instance Attribute Details
#rows ⇒ ::Google::Cloud::Bigquery::Storage::V1::ProtoRows
Returns Required. Serialized row data in protobuf message format. Currently, the backend expects the serialized rows to adhere to proto2 semantics when appending rows, particularly with respect to how default values are encoded.
343 344 345 346 |
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 343 class ProtoData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |
#writer_schema ⇒ ::Google::Cloud::Bigquery::Storage::V1::ProtoSchema
Returns Optional. The protocol buffer schema used to serialize the data. Provide this value whenever:
You send the first request of an RPC connection.
You change the input schema.
You specify a new destination table.
343 344 345 346 |
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 343 class ProtoData include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods end |