Class: Google::Cloud::Bigquery::Storage::V1::AppendRowsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/storage/v1/storage.rb

Overview

Response message for AppendRows.

Defined Under Namespace

Classes: AppendResult

Instance Attribute Summary collapse

Instance Attribute Details

#append_result::Google::Cloud::Bigquery::Storage::V1::AppendRowsResponse::AppendResult

Returns Result if the append is successful.

Note: The following fields are mutually exclusive: append_result, error. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:



418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 418

class AppendRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AppendResult is returned for successful append requests.
  # @!attribute [rw] offset
  #   @return [::Google::Protobuf::Int64Value]
  #     The row offset at which the last append occurred. The offset will not be
  #     set if appending using default streams.
  class AppendResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#error::Google::Rpc::Status

Returns Error returned when problems were encountered. If present, it indicates rows were not accepted into the system. Users can retry or continue with other append requests within the same connection.

Additional information about error signalling:

ALREADY_EXISTS: Happens when an append specified an offset, and the backend already has received data at this offset. Typically encountered in retry scenarios, and can be ignored.

OUT_OF_RANGE: Returned when the specified offset in the stream is beyond the current end of the stream.

INVALID_ARGUMENT: Indicates a malformed request or data.

ABORTED: Request processing is aborted because of prior failures. The request can be retried if previous failure is addressed.

INTERNAL: Indicates server side error(s) that can be retried.

Note: The following fields are mutually exclusive: error, append_result. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Rpc::Status)

    Error returned when problems were encountered. If present, it indicates rows were not accepted into the system. Users can retry or continue with other append requests within the same connection.

    Additional information about error signalling:

    ALREADY_EXISTS: Happens when an append specified an offset, and the backend already has received data at this offset. Typically encountered in retry scenarios, and can be ignored.

    OUT_OF_RANGE: Returned when the specified offset in the stream is beyond the current end of the stream.

    INVALID_ARGUMENT: Indicates a malformed request or data.

    ABORTED: Request processing is aborted because of prior failures. The request can be retried if previous failure is addressed.

    INTERNAL: Indicates server side error(s) that can be retried.

    Note: The following fields are mutually exclusive: error, append_result. If a field in that set is populated, all other fields in the set will automatically be cleared.



418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 418

class AppendRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AppendResult is returned for successful append requests.
  # @!attribute [rw] offset
  #   @return [::Google::Protobuf::Int64Value]
  #     The row offset at which the last append occurred. The offset will not be
  #     set if appending using default streams.
  class AppendResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#row_errors::Array<::Google::Cloud::Bigquery::Storage::V1::RowError>

Returns If a request failed due to corrupted rows, no rows in the batch will be appended. The API will return row level error info, so that the caller can remove the bad rows and retry the request.

Returns:

  • (::Array<::Google::Cloud::Bigquery::Storage::V1::RowError>)

    If a request failed due to corrupted rows, no rows in the batch will be appended. The API will return row level error info, so that the caller can remove the bad rows and retry the request.



418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 418

class AppendRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AppendResult is returned for successful append requests.
  # @!attribute [rw] offset
  #   @return [::Google::Protobuf::Int64Value]
  #     The row offset at which the last append occurred. The offset will not be
  #     set if appending using default streams.
  class AppendResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#updated_schema::Google::Cloud::Bigquery::Storage::V1::TableSchema

Returns If backend detects a schema update, pass it to user so that user can use it to input new type of message. It will be empty when no schema updates have occurred.

Returns:



418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 418

class AppendRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AppendResult is returned for successful append requests.
  # @!attribute [rw] offset
  #   @return [::Google::Protobuf::Int64Value]
  #     The row offset at which the last append occurred. The offset will not be
  #     set if appending using default streams.
  class AppendResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end

#write_stream::String

Returns The target of the append operation. Matches the write_stream in the corresponding request.

Returns:

  • (::String)

    The target of the append operation. Matches the write_stream in the corresponding request.



418
419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 418

class AppendRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # AppendResult is returned for successful append requests.
  # @!attribute [rw] offset
  #   @return [::Google::Protobuf::Int64Value]
  #     The row offset at which the last append occurred. The offset will not be
  #     set if appending using default streams.
  class AppendResult
    include ::Google::Protobuf::MessageExts
    extend ::Google::Protobuf::MessageExts::ClassMethods
  end
end