Module: Google::Cloud::Bigquery::Storage::V1::AvroSerializationOptions::PicosTimestampPrecision

Defined in:
proto_docs/google/cloud/bigquery/storage/v1/avro.rb

Overview

The precision of the timestamp value in the Avro message. This precision will only be applied to the column(s) with the TIMESTAMP_PICOS type.

Constant Summary collapse

PICOS_TIMESTAMP_PRECISION_UNSPECIFIED =

Unspecified timestamp precision. The default precision is microseconds.

0
TIMESTAMP_PRECISION_MICROS =

Timestamp values returned by Read API will be truncated to microsecond level precision. The value will be encoded as Avro TIMESTAMP type in a 64 bit integer.

1
TIMESTAMP_PRECISION_NANOS =

Timestamp values returned by Read API will be truncated to nanosecond level precision. The value will be encoded as Avro TIMESTAMP type in a 64 bit integer.

2
TIMESTAMP_PRECISION_PICOS =

Read API will return full precision picosecond value. The value will be encoded as a string which conforms to ISO 8601 format.

3