Class: Google::Cloud::Bigquery::Storage::V1::ReadRowsResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/bigquery/storage/v1/storage.rb

Overview

Response from calling ReadRows may include row data, progress and throttling information.

Instance Attribute Summary collapse

Instance Attribute Details

#arrow_record_batch::Google::Cloud::Bigquery::Storage::V1::ArrowRecordBatch

Returns Serialized row data in Arrow RecordBatch format.

Note: The following fields are mutually exclusive: arrow_record_batch, avro_rows. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Bigquery::Storage::V1::ArrowRecordBatch)

    Serialized row data in Arrow RecordBatch format.

    Note: The following fields are mutually exclusive: arrow_record_batch, avro_rows. If a field in that set is populated, all other fields in the set will automatically be cleared.



164
165
166
167
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 164

class ReadRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#arrow_schema::Google::Cloud::Bigquery::Storage::V1::ArrowSchema (readonly)

Returns Output only. Arrow schema.

Note: The following fields are mutually exclusive: arrow_schema, avro_schema. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Bigquery::Storage::V1::ArrowSchema)

    Output only. Arrow schema.

    Note: The following fields are mutually exclusive: arrow_schema, avro_schema. If a field in that set is populated, all other fields in the set will automatically be cleared.



164
165
166
167
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 164

class ReadRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#avro_rows::Google::Cloud::Bigquery::Storage::V1::AvroRows

Returns Serialized row data in AVRO format.

Note: The following fields are mutually exclusive: avro_rows, arrow_record_batch. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Bigquery::Storage::V1::AvroRows)

    Serialized row data in AVRO format.

    Note: The following fields are mutually exclusive: avro_rows, arrow_record_batch. If a field in that set is populated, all other fields in the set will automatically be cleared.



164
165
166
167
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 164

class ReadRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#avro_schema::Google::Cloud::Bigquery::Storage::V1::AvroSchema (readonly)

Returns Output only. Avro schema.

Note: The following fields are mutually exclusive: avro_schema, arrow_schema. If a field in that set is populated, all other fields in the set will automatically be cleared.

Returns:

  • (::Google::Cloud::Bigquery::Storage::V1::AvroSchema)

    Output only. Avro schema.

    Note: The following fields are mutually exclusive: avro_schema, arrow_schema. If a field in that set is populated, all other fields in the set will automatically be cleared.



164
165
166
167
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 164

class ReadRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#row_count::Integer

Returns Number of serialized rows in the rows block.

Returns:

  • (::Integer)

    Number of serialized rows in the rows block.



164
165
166
167
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 164

class ReadRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#stats::Google::Cloud::Bigquery::Storage::V1::StreamStats

Returns Statistics for the stream.

Returns:



164
165
166
167
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 164

class ReadRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#throttle_state::Google::Cloud::Bigquery::Storage::V1::ThrottleState

Returns Throttling state. If unset, the latest response still describes the current throttling status.

Returns:



164
165
166
167
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 164

class ReadRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#uncompressed_byte_size::Integer

Returns Optional. If the row data in this ReadRowsResponse is compressed, then uncompressed byte size is the original size of the uncompressed row data. If it is set to a value greater than 0, then decompress into a buffer of size uncompressed_byte_size using the compression codec that was requested during session creation time and which is specified in TableReadOptions.response_compression_codec in ReadSession. This value is not set if no response_compression_codec was not requested and it is -1 if the requested compression would not have reduced the size of this ReadRowsResponse's row data. This attempts to match Apache Arrow's behavior described here https://github.com/apache/arrow/issues/15102 where the uncompressed length may be set to -1 to indicate that the data that follows is not compressed, which can be useful for cases where compression does not yield appreciable savings. When uncompressed_byte_size is not greater than 0, the client should skip decompression.

Returns:

  • (::Integer)

    Optional. If the row data in this ReadRowsResponse is compressed, then uncompressed byte size is the original size of the uncompressed row data. If it is set to a value greater than 0, then decompress into a buffer of size uncompressed_byte_size using the compression codec that was requested during session creation time and which is specified in TableReadOptions.response_compression_codec in ReadSession. This value is not set if no response_compression_codec was not requested and it is -1 if the requested compression would not have reduced the size of this ReadRowsResponse's row data. This attempts to match Apache Arrow's behavior described here https://github.com/apache/arrow/issues/15102 where the uncompressed length may be set to -1 to indicate that the data that follows is not compressed, which can be useful for cases where compression does not yield appreciable savings. When uncompressed_byte_size is not greater than 0, the client should skip decompression.



164
165
166
167
# File 'proto_docs/google/cloud/bigquery/storage/v1/storage.rb', line 164

class ReadRowsResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end