Class: Google::Cloud::Bigquery::Storage::V1::ArrowSerializationOptions
- Inherits:
-
Object
- Object
- Google::Cloud::Bigquery::Storage::V1::ArrowSerializationOptions
- Extended by:
- Protobuf::MessageExts::ClassMethods
- Includes:
- Protobuf::MessageExts
- Defined in:
- proto_docs/google/cloud/bigquery/storage/v1/arrow.rb
Overview
Contains options specific to Arrow Serialization.
Defined Under Namespace
Modules: CompressionCodec, PicosTimestampPrecision
Instance Attribute Summary collapse
-
#buffer_compression ⇒ ::Google::Cloud::Bigquery::Storage::V1::ArrowSerializationOptions::CompressionCodec
The compression codec to use for Arrow buffers in serialized record batches.
-
#picos_timestamp_precision ⇒ ::Google::Cloud::Bigquery::Storage::V1::ArrowSerializationOptions::PicosTimestampPrecision
Optional.
Instance Attribute Details
#buffer_compression ⇒ ::Google::Cloud::Bigquery::Storage::V1::ArrowSerializationOptions::CompressionCodec
Returns The compression codec to use for Arrow buffers in serialized record batches.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/bigquery/storage/v1/arrow.rb', line 62 class ArrowSerializationOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Compression codec's supported by Arrow. module CompressionCodec # If unspecified no compression will be used. COMPRESSION_UNSPECIFIED = 0 # LZ4 Frame (https://github.com/lz4/lz4/blob/dev/doc/lz4_Frame_format.md) LZ4_FRAME = 1 # Zstandard compression. ZSTD = 2 end # The precision of the timestamp value in the Avro message. This precision # will **only** be applied to the column(s) with the `TIMESTAMP_PICOS` type. module PicosTimestampPrecision # Unspecified timestamp precision. The default precision is microseconds. PICOS_TIMESTAMP_PRECISION_UNSPECIFIED = 0 # Timestamp values returned by Read API will be truncated to microsecond # level precision. The value will be encoded as Arrow TIMESTAMP type in a # 64 bit integer. TIMESTAMP_PRECISION_MICROS = 1 # Timestamp values returned by Read API will be truncated to nanosecond # level precision. The value will be encoded as Arrow TIMESTAMP type in a # 64 bit integer. TIMESTAMP_PRECISION_NANOS = 2 # Read API will return full precision picosecond value. The value will be # encoded as a string which conforms to ISO 8601 format. TIMESTAMP_PRECISION_PICOS = 3 end end |
#picos_timestamp_precision ⇒ ::Google::Cloud::Bigquery::Storage::V1::ArrowSerializationOptions::PicosTimestampPrecision
Returns Optional. Set timestamp precision option. If not set, the default precision is microseconds.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'proto_docs/google/cloud/bigquery/storage/v1/arrow.rb', line 62 class ArrowSerializationOptions include ::Google::Protobuf::MessageExts extend ::Google::Protobuf::MessageExts::ClassMethods # Compression codec's supported by Arrow. module CompressionCodec # If unspecified no compression will be used. COMPRESSION_UNSPECIFIED = 0 # LZ4 Frame (https://github.com/lz4/lz4/blob/dev/doc/lz4_Frame_format.md) LZ4_FRAME = 1 # Zstandard compression. ZSTD = 2 end # The precision of the timestamp value in the Avro message. This precision # will **only** be applied to the column(s) with the `TIMESTAMP_PICOS` type. module PicosTimestampPrecision # Unspecified timestamp precision. The default precision is microseconds. PICOS_TIMESTAMP_PRECISION_UNSPECIFIED = 0 # Timestamp values returned by Read API will be truncated to microsecond # level precision. The value will be encoded as Arrow TIMESTAMP type in a # 64 bit integer. TIMESTAMP_PRECISION_MICROS = 1 # Timestamp values returned by Read API will be truncated to nanosecond # level precision. The value will be encoded as Arrow TIMESTAMP type in a # 64 bit integer. TIMESTAMP_PRECISION_NANOS = 2 # Read API will return full precision picosecond value. The value will be # encoded as a string which conforms to ISO 8601 format. TIMESTAMP_PRECISION_PICOS = 3 end end |